==> haskell-pipes-http-1.0.6-761-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-vlyaFeOqprFHDTLcL6LpA
key:                  pipes-http-1.0.6-vlyaFeOqprFHDTLcL6LpA
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  f230658ca563ad138d2517e5b1a9344e
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-vlyaFeOqprFHDTLcL6LpA
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http-client-0.7.19-76DosIrYZ8GJOiYGyhGmc9
    http-client-tls-0.3.6.4-J61axw4VOrbKDwJUgwBVs6
    pipes-4.3.16-1cweUqtcPZw1FLNBrZvQ72

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.6-762-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-3Wpjtn2ge2M5PmCiIpbQvN
key:                  pipes-http-1.0.6-3Wpjtn2ge2M5PmCiIpbQvN
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  53aa2d9478ecbb93443dfb7ffe7e8c6a
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-3Wpjtn2ge2M5PmCiIpbQvN
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    http-client-0.7.19-ITPZXASBEGHLmOi4NfdGY8
    http-client-tls-0.3.6.4-2TpGPIcpPZAJDvilQsJ18b
    pipes-4.3.16-1cweUqtcPZw1FLNBrZvQ72

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
